changeset 107073:163cd2024354

* ediff-util.el (ediff-file-checked-in-p): Replace '(nil CVS) by '(RCS SCCS) with inverted condition.
author Juri Linkov <juri@jurta.org>
date Wed, 03 Feb 2010 00:28:57 +0200
parents abe576120f76
children e4a4161df485
files lisp/ChangeLog lisp/ediff-util.el
diffstat 2 files changed, 7 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Tue Feb 02 12:19:36 2010 +0100
+++ b/lisp/ChangeLog	Wed Feb 03 00:28:57 2010 +0200
@@ -1,3 +1,8 @@
+2010-02-02  Juri Linkov  <juri@jurta.org>
+
+	* ediff-util.el (ediff-file-checked-in-p): Replace '(nil CVS) by
+	'(RCS SCCS) with inverted condition.
+
 2010-02-02  Michael Albinus  <michael.albinus@gmx.de>
 
 	* net/ange-ftp.el (ange-ftp-skip-msgs): Ignore all ""^500 .*AUTH"
--- a/lisp/ediff-util.el	Tue Feb 02 12:19:36 2010 +0100
+++ b/lisp/ediff-util.el	Wed Feb 03 00:28:57 2010 +0200
@@ -1126,8 +1126,8 @@
 
 (defun ediff-file-checked-in-p (file)
   (and (featurep 'vc-hooks)
-       ;; CVS files are considered not checked in
-       (not (memq (vc-backend file) '(nil CVS)))
+       ;; Only RCS and SCCS files are considered checked in
+       (memq (vc-backend file) '(RCS SCCS))
        (if (fboundp 'vc-state)
 	   (and
 	    (not (memq (vc-state file) '(edited needs-merge)))